
# Scripts

This script uses the example data set in section 3 of the paper. The inputs are Tables 1-3; the matching decisions are those reported in Table 4. To run it:
1. install ppe_match
2. change the directory in the code with the local directory that contains the test data (Table1.csv, Table2.csv, Table3.csv, Table4.csv)
3. the file "tests solved manually.xlsx" contains the details on how the metrics are computated



